#ifndef _LAYOUTMANAGER_H
#define _LAYOUTMANAGER_H

#include "stdafx.h"
#include <list>

/* this class manages simple layouts for Win32 applications.
   Written and (C) 2001 by eolson@mit.edu

1. Setup the resource the way you want it (and enable resizing!)

2. Initialize the Layout Manager in InitInstance():

	m_layoutmanager.setOwner(this);
	CRect crect;
	crect.top=0; crect.bottom=0; crect.left=0; crect.right=0;
	GetClientRect(&crect);
	m_layoutmanager.setOrigSize(&crect);
	m_layoutmanager.add(&m_ciphertext,1.0,0.0,LayoutManager::kTopLeft);
	m_layoutmanager.add(&m_clues,1.0,0,LayoutManager::kTopLeft);
	m_layoutmanager.add(&m_solutions,1.0,1,LayoutManager::kBottomLeft);
	m_layoutmanager.add(&m_progress,1.0,0,LayoutManager::kTopRight);


3. You must call the layout manager from OnSize and OnGetMinMaxInfo calls.

void CDecryptoDlg::OnSize(UINT nType, int cx, int cy) 
{
	CDialog::OnSize(nType, cx, cy);
	
	m_layoutmanager.OnSize(nType,cx,cy);
}

void CDecryptoDlg::OnGetMinMaxInfo( MINMAXINFO FAR* lpMMI )
{
	m_layoutmanager.OnGetMinMaxInfo(lpMMI);
}
*/

class LayoutRecord
{
public:
	LayoutRecord(CWnd *element, float hgrow, float vgrow, int anchor, CRect origPos)
	{
		m_element=element;
		m_hgrow=hgrow;
		m_vgrow=vgrow;
		m_origPos=origPos;
		m_anchor=anchor;
	}

	CWnd *m_element;
	float m_hgrow;
	float m_vgrow;
	CRect m_origPos;
	int m_anchor;

};

class LayoutManager
{
public:
	enum { kTopLeft, kBottomLeft, kTopRight, kBottomRight };

	LayoutManager();
	void setOrigSize(CRect *crect);
	void setOwner(CWnd *owner);

	void add(CWnd *element, float hgrow, float vgrow, int anchor);

	void OnSize(UINT nType, int cx, int cy);
	void OnGetMinMaxInfo(MINMAXINFO FAR* lpMMI);

protected:
	std::list<LayoutRecord*> m_elements;
	CRect m_origSize;
	CWnd *m_owner;
	bool m_origSizeInitialized;
};


#endif
